<?php

namespace Koneko\VuexyWebsiteAdmin\Application\Bootstrap\Context;

use Illuminate\Http\Request;
use Koneko\VuexyWebsiteAdmin\Models\WebsiteSite;

/**
 * 🧠 Resolve contexto de sitio activo en modo multisite
 */
class SiteContext
{
    protected static ?WebsiteSite $resolved = null;

    /**
     * Devuelve el sitio actual (usando cache interna si ya fue resuelto)
     */
    public static function resolve(): ?WebsiteSite
    {
        return static::$resolved;
    }

    /**
     * Resuelve el sitio activo desde el request actual (dominio o path)
     */
    public static function resolveFromRequest(Request $request): ?WebsiteSite
    {
        // Evita doble resolución
        if (static::$resolved instanceof WebsiteSite) {
            return static::$resolved;
        }

        $host = $request->getHost();
        $path = trim($request->path(), '/');

        // 🧪 Estrategia 1: dominio exacto
        $site = WebsiteSite::where('domain', $host)->first();

        // 🧪 Estrategia 2: subdominio match (ej. tienda1.koneko.mx)
        if (!$site && str_contains($host, '.')) {
            $subdomain = explode('.', $host)[0];
            $site = WebsiteSite::where('subdomain', $subdomain)->first();
        }

        // 🧪 Estrategia 3: segmento del path (ej. /site-x/*)
        if (!$site && str_contains($path, '/')) {
            $firstSegment = explode('/', $path)[0];
            $site = WebsiteSite::where('slug', $firstSegment)->first();
        }

        // Establece contexto (null si no hay match)
        static::$resolved = $site;

        return $site;
    }

    /**
     * Fuerza un sitio específico (desde sesión o entorno controlado)
     */
    public static function set(WebsiteSite $site): void
    {
        static::$resolved = $site;
    }

    /**
     * Limpia el contexto (en tests o entorno controlado)
     */
    public static function forget(): void
    {
        static::$resolved = null;
    }
}
